@@ -77,6 +77,11 @@ def keeper(
         envvar=f"{PREFIX}_AGENT_IPS",
         show_envvar=False,
     ),
+    signing_key: str = typer.Option(
+        "",
+        envvar=f"{PREFIX}_SIGNING_KEY",
+        show_envvar=False,
+    ),
 ):
 
     agent_ips = agent_ips.split(",")
@@ -87,6 +92,7 @@ def keeper(
         comms_port=comms_port,
         app_name=app_name,
         agent_ips=agent_ips,
+        signing_key=signing_key,
     )
 
     log = logging.getLogger("fluxvault")
@@ -155,13 +161,21 @@ def agent(
         show_envvar=False,
         help="Comma seperated addresses to whitelist",
     ),
-    disable_authentication: bool = typer.Option(
-        False,
-        "--disable-authentication",
-        "-a",
-        envvar=f"{PREFIX}_DISABLE_AUTHENTICATION",
+    verify_source_address: bool = typer.Option(
+        True,
+        "--verify-source-address",
+        "-z",
+        envvar=f"{PREFIX}_VERIFY_SOURCE_ADDRESS",
         show_envvar=False,
-        help="Are you sure you want to do this?",
+        help="Matches source ip to your whitelist",
+    ),
+    signed_vault_connections: bool = typer.Option(
+        False,
+        "--signed-vault-connections",
+        "-k",
+        envvar=f"{PREFIX}_SIGNED_VAULT_CONNECTIONS",
+        show_envvar=False,
+        help="Expects all keeper connections to be signed",
     ),
 ):
 
@@ -178,7 +192,8 @@ def agent(
         managed_files=managed_files,
         working_dir=working_dir,
         whitelisted_addresses=whitelisted_addresses,
-        authenticate_vault=not disable_authentication,
+        verify_source_address=verify_source_address,
+        signed_vault_connections=signed_vault_connections,
     )
 
     agent.run()
